==> yak-dev-common-2.4.18-sources.jar: org/crazyyak/dev/common/DateUtils.java <==
package org.crazyyak.dev.common;

import org.joda.time.*;

import java.util.Calendar;

public class DateUtils {

  public static final DateTimeZone PDT = DateTimeZone.forID("America/Dawson");

  private static DateUtilsFactory factory = new DateUtilsFactory(null);
  
  private DateUtils() {
  }

  public static DateUtilsFactory newFactory(DateTimeZone timeZone) {
    return new DateUtilsFactory(timeZone);
  }

  public static LocalTime currentTime() {
    return factory.currentTime();
  }
  public static LocalDateTime currentDateTime() {
    return factory.currentDateTime();
  }
  public static LocalDate currentDate() {
    return factory.currentDate();
  }
  public static LocalDateTime midnightToday() {
    return factory.midnightToday();
  }



  public static LocalDate toLocalDate(Object date) {
    return factory.toLocalDate(date);
  }
  public static LocalDate toLocalDate(String date) {
    return factory.toLocalDate(date);
  }
  public static LocalDate toLocalDate(long date) {
    return factory.toLocalDate(date);
  }
  public static LocalDate toLocalDate(java.util.Date date) {
    return factory.toLocalDate(date);
  }
  public static LocalDate toLocalDate(Calendar date) {
    return factory.toLocalDate(date);
  }
  public static LocalDate toLocalDate(LocalDateTime date) {
    return factory.toLocalDate(date);
  }
  public static LocalDate toLocalDate(DateTime date) {
    return factory.toLocalDate(date);
  }
  public static LocalDate toLocalDate(int year, int month, int day) {
    return factory.toLocalDate(year, month, day);
  }



  public static LocalTime toLocalTime(Object date) {
    return factory.toLocalTime(date);
  }
  public static LocalTime toLocalTime(String date) {
    return factory.toLocalTime(date);
  }
  public static LocalTime toLocalTime(long date) {
    return factory.toLocalTime(date);
  }
  public static LocalTime toLocalTime(java.util.Date date) {
    return factory.toLocalTime(date);
  }
  public static LocalTime toLocalTime(Calendar date) {
    return factory.toLocalTime(date);
  }
  public static LocalTime toLocalTime(LocalDateTime date) {
    return factory.toLocalTime(date);
  }
  public static LocalTime toLocalTime(DateTime date) {
    return factory.toLocalTime(date);
  }
  public static LocalTime toLocalTime(int hourOfDay, int minuteOfHour) {
    return factory.toLocalTime(hourOfDay, minuteOfHour, 0, 0);
  }
  public static LocalTime toLocalTime(int hourOfDay, int minuteOfHour, int secondOfMinute) {
    return factory.toLocalTime(hourOfDay, minuteOfHour, secondOfMinute, 0);
  }
  public static LocalTime toLocalTime(int hourOfDay, int minuteOfHour, int secondOfMinute, int millisOfSecond) {
    return factory.toLocalTime(hourOfDay, minuteOfHour, secondOfMinute, millisOfSecond);
  }



  public static LocalDateTime toLocalDateTime(Object date) {
    return factory.toLocalDateTime(date);
  }
  public static LocalDateTime toLocalDateTime(String date) {
    return factory.toLocalDateTime(date);
  }
  public static LocalDateTime toLocalDateTime(long date) {
    return factory.toLocalDateTime(date);
  }
  public static LocalDateTime toLocalDateTime(java.util.Date date) {
    return factory.toLocalDateTime(date);
  }
  public static LocalDateTime toLocalDateTime(Calendar date) {
    return factory.toLocalDateTime(date);
  }
  public static LocalDateTime toLocalDateTime(LocalDate date) {
    return factory.toLocalDateTime(date);
  }
  public static LocalDateTime toLocalDateTime(DateTime date) {
    return factory.toLocalDateTime(date);
  }
  public static LocalDateTime toLocalDateTime(int year, int monthOfYear, int dayOfMonth) {
    return factory.toLocalDateTime(year, monthOfYear, dayOfMonth, 0, 0, 0, 0);
  }
  public static LocalDateTime toLocalDateTime(int year, int monthOfYear, int dayOfMonth, int hourOfDay, int minuteOfHour) {
    return factory.toLocalDateTime(year, monthOfYear, dayOfMonth, hourOfDay, minuteOfHour, 0, 0);
  }
  public static LocalDateTime toLocalDateTime(int year, int monthOfYear, int dayOfMonth, int hourOfDay, int minuteOfHour, int secondOfMinute) {
    return factory.toLocalDateTime(year, monthOfYear, dayOfMonth, hourOfDay, minuteOfHour, secondOfMinute, 0);
  }
  public static LocalDateTime toLocalDateTime(int year, int monthOfYear, int dayOfMonth, int hourOfDay, int minuteOfHour, int secondOfMinute, int millisOfSecond) {
    return factory.toLocalDateTime(year, monthOfYear, dayOfMonth, hourOfDay, minuteOfHour, secondOfMinute, millisOfSecond);
  }



  public static DateTime toDateTime(Object date) {
    return factory.toDateTime(date);
  }
  public static DateTime toDateTime(String date) {
    return factory.toDateTime(date);
  }
  public static DateTime toDateTime(long date) {
    return factory.toDateTime(date);
  }
  public static DateTime toDateTime(LocalDate date) {
    return factory.toDateTime(date);
  }
  public static DateTime toDateTime(LocalDateTime date) {
    return factory.toDateTime(date);
  }
  public static DateTime toDateTime(java.util.Date date) {
    return factory.toDateTime(date);
  }
  public static DateTime toDateTime(Calendar date) {
    return factory.toDateTime(date);
  }
  public static DateTime toDateTime(int year, int monthOfYear, int dayOfMonth) {
    return factory.toDateTime(year, monthOfYear, dayOfMonth, 0, 0, 0 , 0);
  }
  public static DateTime toDateTime(int year, int monthOfYear, int dayOfMonth, int hourOfDay, int minuteOfHour) {
    return factory.toDateTime(year, monthOfYear, dayOfMonth, hourOfDay, minuteOfHour, 0, 0);
  }
  public static DateTime toDateTime(int year, int monthOfYear, int dayOfMonth, int hourOfDay, int minuteOfHour, int secondOfMinute) {
    return factory.toDateTime(year, monthOfYear, dayOfMonth, hourOfDay, minuteOfHour, secondOfMinute, 0);
  }
  public static DateTime toDateTime(int year, int monthOfYear, int dayOfMonth, int hourOfDay, int minuteOfHour, int secondOfMinute, int millisOfSecond) {
    return factory.toDateTime(year, monthOfYear, dayOfMonth, hourOfDay, minuteOfHour, secondOfMinute, millisOfSecond);
  }
}

==> yak-dev-common-2.4.19-sources.jar: org/crazyyak/dev/common/DateUtils.java <==
package org.crazyyak.dev.common;

import org.joda.time.*;

import java.util.Calendar;
import java.util.Date;
import java.util.GregorianCalendar;

public class DateUtils {

  public static final DateTimeZone PDT = DateTimeZone.forID("America/Dawson");

  private static DateUtilsFactory factory = new DateUtilsFactory(null);
  
  private DateUtils() {
  }

  public static DateUtilsFactory newFactory(DateTimeZone timeZone) {
    return new DateUtilsFactory(timeZone);
  }

  public static LocalTime currentTime() {
    return factory.currentTime();
  }
  public static LocalDateTime currentDateTime() {
    return factory.currentDateTime();
  }
  public static LocalDate currentDate() {
    return factory.currentDate();
  }
  public static LocalDateTime midnightToday() {
    return factory.midnightToday();
  }



  public static LocalDate toLocalDate(Object date) {
    return factory.toLocalDate(date);
  }
  public static LocalDate toLocalDate(String date) {
    return factory.toLocalDate(date);
  }
  public static LocalDate toLocalDate(long date) {
    return factory.toLocalDate(date);
  }
  public static LocalDate toLocalDate(java.util.Date date) {
    return factory.toLocalDate(date);
  }
  public static LocalDate toLocalDate(Calendar date) {
    return factory.toLocalDate(date);
  }
  public static LocalDate toLocalDate(LocalDateTime date) {
    return factory.toLocalDate(date);
  }
  public static LocalDate toLocalDate(DateTime date) {
    return factory.toLocalDate(date);
  }
  public static LocalDate toLocalDate(int year, int month, int day) {
    return factory.toLocalDate(year, month, day);
  }



  public static LocalTime toLocalTime(Object date) {
    return factory.toLocalTime(date);
  }
  public static LocalTime toLocalTime(String date) {
    return factory.toLocalTime(date);
  }
  public static LocalTime toLocalTime(long date) {
    return factory.toLocalTime(date);
  }
  public static LocalTime toLocalTime(java.util.Date date) {
    return factory.toLocalTime(date);
  }
  public static LocalTime toLocalTime(Calendar date) {
    return factory.toLocalTime(date);
  }
  public static LocalTime toLocalTime(LocalDateTime date) {
    return factory.toLocalTime(date);
  }
  public static LocalTime toLocalTime(DateTime date) {
    return factory.toLocalTime(date);
  }
  public static LocalTime toLocalTime(int hourOfDay, int minuteOfHour) {
    return factory.toLocalTime(hourOfDay, minuteOfHour, 0, 0);
  }
  public static LocalTime toLocalTime(int hourOfDay, int minuteOfHour, int secondOfMinute) {
    return factory.toLocalTime(hourOfDay, minuteOfHour, secondOfMinute, 0);
  }
  public static LocalTime toLocalTime(int hourOfDay, int minuteOfHour, int secondOfMinute, int millisOfSecond) {
    return factory.toLocalTime(hourOfDay, minuteOfHour, secondOfMinute, millisOfSecond);
  }



  public static LocalDateTime toLocalDateTime(Object date) {
    return factory.toLocalDateTime(date);
  }
  public static LocalDateTime toLocalDateTime(String date) {
    return factory.toLocalDateTime(date);
  }
  public static LocalDateTime toLocalDateTime(long date) {
    return factory.toLocalDateTime(date);
  }
  public static LocalDateTime toLocalDateTime(java.util.Date date) {
    return factory.toLocalDateTime(date);
  }
  public static LocalDateTime toLocalDateTime(Calendar date) {
    return factory.toLocalDateTime(date);
  }
  public static LocalDateTime toLocalDateTime(LocalDate date) {
    return factory.toLocalDateTime(date);
  }
  public static LocalDateTime toLocalDateTime(DateTime date) {
    return factory.toLocalDateTime(date);
  }
  public static LocalDateTime toLocalDateTime(int year, int monthOfYear, int dayOfMonth) {
    return factory.toLocalDateTime(year, monthOfYear, dayOfMonth, 0, 0, 0, 0);
  }
  public static LocalDateTime toLocalDateTime(int year, int monthOfYear, int dayOfMonth, int hourOfDay, int minuteOfHour) {
    return factory.toLocalDateTime(year, monthOfYear, dayOfMonth, hourOfDay, minuteOfHour, 0, 0);
  }
  public static LocalDateTime toLocalDateTime(int year, int monthOfYear, int dayOfMonth, int hourOfDay, int minuteOfHour, int secondOfMinute) {
    return factory.toLocalDateTime(year, monthOfYear, dayOfMonth, hourOfDay, minuteOfHour, secondOfMinute, 0);
  }
  public static LocalDateTime toLocalDateTime(int year, int monthOfYear, int dayOfMonth, int hourOfDay, int minuteOfHour, int secondOfMinute, int millisOfSecond) {
    return factory.toLocalDateTime(year, monthOfYear, dayOfMonth, hourOfDay, minuteOfHour, secondOfMinute, millisOfSecond);
  }



  public static DateTime toDateTime(Object date) {
    return factory.toDateTime(date);
  }
  public static DateTime toDateTime(String date) {
    return factory.toDateTime(date);
  }
  public static DateTime toDateTime(long date) {
    return factory.toDateTime(date);
  }
  public static DateTime toDateTime(LocalDate date) {
    return factory.toDateTime(date);
  }
  public static DateTime toDateTime(LocalDateTime date) {
    return factory.toDateTime(date);
  }
  public static DateTime toDateTime(java.util.Date date) {
    return factory.toDateTime(date);
  }
  public static DateTime toDateTime(Calendar date) {
    return factory.toDateTime(date);
  }
  public static DateTime toDateTime(int year, int monthOfYear, int dayOfMonth) {
    return factory.toDateTime(year, monthOfYear, dayOfMonth, 0, 0, 0 , 0);
  }
  public static DateTime toDateTime(int year, int monthOfYear, int dayOfMonth, int hourOfDay, int minuteOfHour) {
    return factory.toDateTime(year, monthOfYear, dayOfMonth, hourOfDay, minuteOfHour, 0, 0);
  }
  public static DateTime toDateTime(int year, int monthOfYear, int dayOfMonth, int hourOfDay, int minuteOfHour, int secondOfMinute) {
    return factory.toDateTime(year, monthOfYear, dayOfMonth, hourOfDay, minuteOfHour, secondOfMinute, 0);
  }
  public static DateTime toDateTime(int year, int monthOfYear, int dayOfMonth, int hourOfDay, int minuteOfHour, int secondOfMinute, int millisOfSecond) {
    return factory.toDateTime(year, monthOfYear, dayOfMonth, hourOfDay, minuteOfHour, secondOfMinute, millisOfSecond);
  }

  static public boolean datesEqual(Date dateA, Date dateB) {
    if (dateA == null && dateB == null) {
      return true;
    } else if (dateA == null || dateB == null) {
      return false;
    } else {
      GregorianCalendar calA = new GregorianCalendar();
      calA.setTime(dateA);
      GregorianCalendar calB = new GregorianCalendar();
      calB.setTime(dateB);

      return (calA.get(Calendar.DATE) == calB.get(Calendar.DATE) &&
          calA.get(Calendar.MONTH) == calB.get(Calendar.MONTH) &&
          calA.get(Calendar.YEAR) == calB.get(Calendar.YEAR));
    }
  }

  static public boolean datesNotEqual(Date dateA, Date dateB) {
    return datesEqual(dateA, dateB) == false;
  }
}
